Miscellaneous functions — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

# Miscellaneous functions

## f90calceph_getversion_str

subroutine `f90calceph_getversion_str`(version)

  Parameters: | version [CHARACTER(len=CALCEPH_MAX_CONSTANTNAME), intent(out)] :: version of the library

This function returns the version of the CALCEPH Library, as a string.

Trailing blanks are added to the name version.

    character(len=CALCEPH_MAX_CONSTANTNAME) version

    call f90calceph_getversion_str(version)
    write(*,*) 'library version is ', version